#!/bin/bash
# Parameters for the vdi.launch.session

#  --name            <session name> (Default: the service name)
#  --host            <host>  
#  --queue           <queue> (Default: job scheduler default or the value configured in
#                    EF_TOP/conf/plugins/interactive/interactive.efconf)
#  --project         <project>
#  --submitopts      <scheduler options> quoted string with the extra options passed verbatim
#                    to the jobmanager submission command
#  --close-on-exit   flag parameter to automatically close the session when the specified application
#                    launcher script exits or the monitored canary process terminates 
#  --canaryprocess   <process name> (Windows only) the name of the process to monitor for close-on-exit
#                    (Default: explorer.exe)
#  --logintimeout    <logintimeout> (Windows only) time in seconds to wait for user to login once the
#                    session is started (Default: inherited from interactive or scheduler configuration,
#                    usually 600 sec)
#  --loglevel        <level> verbosity of the session log (level range: 0 - 4) (Default: value configured
#                    in EF_TOP/conf/plugins/interactive/interactive.efconf, usually 3 - INFO)
#  --no-connect      flag parameter to avoid EF to automatically download the session connection file
#                    on session submission
#  --<remote>-*      <value> specific parameters for the remote visualization technology 
#                    (e.g. dcv2, etc.)
#  --cwd             <path> the path to the remote working directory where the command will be launched
#                    (Default: depends on the underlying scheduler configuration)

#  examples

#  vdi.launch.session --name "My Session" --submitopts "-n ${NCORES} -q ${QUEUE}"
#  where NCORES and QUEUE are options ID from the service editor

instance=$(echo "${instance_queue}" | awk '{print $1}')
queue=$(echo "${instance_queue}" | awk '{print $2}')

if [[ $queue == *"gpu"* ]]; then
  vdi.launch.session --name "GPU Linux Desktop" --queue dcv-gpu --submitopts "-C ${instance}"
else
  vdi.launch.session --name "Linux Desktop" --queue dcv --submitopts "-C ${instance}"
fi